#Contributing
* Let PEP8 be your guide.
* Please include tests if new code isn't covered by existing tests
* Please [squash the commits in your Pull request into a single commit](http://gitready.com/advanced/2009/02/10/squashing-commits-with-rebase.html). Unless
there are some extenuating circumstances why you think you shouldn't.
* Have fun
